summaryrefslogtreecommitdiff
path: root/sys/dev/isa/if_hp.c
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:06:49 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:06:49 +0000
commit19c4b654cc723df0e419fd9f12197f491b1bc1d4 (patch)
treee1ec3cdc5db2c1ca3593846ae053d0595186ead5 /sys/dev/isa/if_hp.c
parent043773b2a500f1f422b5db3eca46befb28d8a7af (diff)
from netbsd:
The IST_* and IPL_* constants are not bus-specific; don't treat them as such. Change splimp -> splnet in Ethernet, ARCnet, and FDDI drivers.
Diffstat (limited to 'sys/dev/isa/if_hp.c')
-rw-r--r--sys/dev/isa/if_hp.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/isa/if_hp.c b/sys/dev/isa/if_hp.c
index d0117ae2839..aeebb013df3 100644
--- a/sys/dev/isa/if_hp.c
+++ b/sys/dev/isa/if_hp.c
@@ -162,7 +162,7 @@ hpprobe(dvp)
#endif
hpc = (ns->ns_port = dvp->id_iobase + 0x10);
- s = splimp();
+ s = splnet();
ns->hp_irq = ffs(dvp->id_irq) - 1;
@@ -441,7 +441,7 @@ hpinit(unit)
if (ifp->if_flags & IFF_RUNNING)
return;
- s = splimp();
+ s = splnet();
#ifdef HP_DEBUG
printf("hpinit: hp%d at 0x%x irq %d\n", unit, hpc, (int) ns->hp_irq);
@@ -505,7 +505,7 @@ hpinit(unit)
* Setup output on interface.
* Get another datagram to send off of the interface queue,
* and map it to the interface before starting the output.
* called only at splimp or interrupt level.
*/
hpstart(ifp)
struct ifnet *ifp;
@@ -926,7 +926,7 @@ hpioctl(ifp, cmd, data)
register struct ifaddr *ifa = (struct ifaddr *) data;
struct hp_softc *ns = &hp_softc[ifp->if_unit];
struct ifreq *ifr = (struct ifreq *) data;
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
@@ -505,7 +505,7 @@ hpinit(unit)
* Get another datagram to send off of the interface queue,
* and map it to the interface before starting the output.
- * called only at splimp or interrupt level.
+ * called only at splnet or interrupt level.
*/
hpstart(ifp)